export default {
    "message": "The keyword 'yield' is reserved",
    "column": 7,
    "index": 6,
    "lineNumber": 1
}